; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a Global Self-consistent, 
; Hierarchical, High-resolution, Shoreline (GSHHS)  database plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "gshhs_plot.pro" and run it like this::
;       IDL> .RUN gshhs_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 27 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO GSHHS_Plot
 
   ; Set up variables for the plot. Normally, these values would be 
   ; passed into the program as positional and keyword parameters.
   ; Use the intermediate resolution GSHHS data file.
   gshhsFile = "gshhs_i.b"
   
   ; Open a display window.
   cgDisplay, 700, 800
   
   ; Create two plots. The first uses the "Map_Set" method. The second
   ; use the "Map_Proj_Init" method. Set up the upper map projection.
   position = [0.05, 0.58, 0.95, 0.93]
   
   ; Fill the map projection with a water color.
   cgColorfill, Position=position, Color='sky blue'
   
   ; Set up a map projection with cgMap_Set.
   cgMap_Set, -25.0, 135.0, Position=position, /Mercator, Scale=64e6, Color='black', /NoErase

   ; Add the shoreline database information.
   cgMap_GSHHS, gshhsFile, Fill=1, Level=3, Color='black', /Outline  

   ; Draw a map grid.
   cgMap_Grid, Color='charcoal', /Label
   
   ; Add a plot title.
   cgText, 0.5, 0.95, Alignment=0.5, /Normal, 'Australia and Surrounding Islands', Font=0
   
   
   ; Set up the 2nd plot using the cgMap coordinate object.
   position = [0.05, 0.05, 0.95, 0.45]
   
   ; Set up the map coordinate object.
   mapCoord = Obj_New('cgMap', "Lambert Azimuthal", Limit=[40, -95, 50, -75], $
      Center_Lat=45, Center_Lon=-85)
   mapCoord -> SetProperty, Position=position, /Draw
   
   ; Add the shoreline database information.
   cgMap_GSHHS, gshhsFile, /Fill, Level=3, Map_Structure=mapCoord, $
      Water='DODGER BLUE', /Outline, Color='charcoal'
      
   ; Draw a map grid.
   cgMap_Grid, /Label, /Box, Color='charcoal', Map_Structure=mapCoord
   
   ; Add a plot title.
   cgText, 0.5, 0.49, 'Great Lakes Region', Font=0, /Normal, Alignment=0.5
      
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  GSHHS_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'GSHHS_Plot',  WBackground='white', WXSize=700, WYSize=800, $
    WTitle='GSHHS Shoreline Data in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'gshhs_plot.ps'
  GSHHS_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'gshhs_plot.ps', /PNG, /Portrait

END